@@ -41,6 +41,9 @@ class ReadEPROFILE:
             :class:`xarray.Dataset`
         """
         ds = xr.open_dataset(self.path, decode_times=True)
+        # in CEDA archive, dimensions come as (altitude, time). Transpose all variables which have altitude as dimension.
+        if ds.latitude.dims[0]=='altitude':
+            ds = ds.transpose(..., 'altitude')
         # replace wavelength with actual value in attenuated backscatter longname
         ds.attenuated_backscatter_0.attrs["long_name"] = ds.attenuated_backscatter_0.long_name.replace(
             "at wavelength 0", f"@ {int(ds.l0_wavelength.data)} nm"
